Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4278)

Unified Diff: chrome/browser/ui/webui/options2/chromeos/user_image_source2.h

Issue 10454044: Added support for animated/nonanimated user image. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Added clarifying comment. Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options2/chromeos/user_image_source2.h
diff --git a/chrome/browser/ui/webui/options2/chromeos/user_image_source2.h b/chrome/browser/ui/webui/options2/chromeos/user_image_source2.h
index 6bea08e2c26b659914e56db6e891066e319d19d5..b82078d944a44f53d26a2de65007a27383f477a4 100644
--- a/chrome/browser/ui/webui/options2/chromeos/user_image_source2.h
+++ b/chrome/browser/ui/webui/options2/chromeos/user_image_source2.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -28,11 +28,13 @@ class UserImageSource : public ChromeURLDataManager::DataSource {
bool is_incognito,
int request_id) OVERRIDE;
- virtual std::string GetMimeType(const std::string&) const OVERRIDE;
+ virtual std::string GetMimeType(const std::string& path) const OVERRIDE;
- // Returns PNG encoded image for user with specified email.
- // If there's no user with such email, returns the default image.
- std::vector<unsigned char> GetUserImage(const std::string& email) const;
+ // Returns PNG or GIF (when possible and if |is_image_animated| flag
+ // is true) encoded image for user with specified email. If there's
+ // no user with such email, returns the default image.
+ std::vector<unsigned char> GetUserImage(const std::string& email,
+ bool is_image_animated) const;
private:
virtual ~UserImageSource();

Powered by Google App Engine
This is Rietveld 408576698